Home
last modified time | relevance | path

Searched refs:__v (Results 1 – 25 of 81) sorted by relevance

1234

/llvm-project-15.0.7/clang/test/SemaCXX/Inputs/
H A Dstd-compare.h76 return __v.__is_ordered() && __v.__value_ == 0;
79 return __v.__is_ordered() && __v.__value_ < 0;
82 return __v.__is_ordered() && __v.__value_ <= 0;
85 return __v.__is_ordered() && __v.__value_ > 0;
88 return __v.__is_ordered() && __v.__value_ >= 0;
91 return __v.__is_ordered() && 0 == __v.__value_;
94 return __v.__is_ordered() && 0 < __v.__value_;
97 return __v.__is_ordered() && 0 <= __v.__value_;
100 return __v.__is_ordered() && 0 > __v.__value_;
103 return __v.__is_ordered() && 0 >= __v.__value_;
[all …]
/llvm-project-15.0.7/clang/test/PCH/Inputs/
H A Dstd-compare.h76 return __v.__is_ordered() && __v.__value_ == 0;
79 return __v.__is_ordered() && __v.__value_ < 0;
82 return __v.__is_ordered() && __v.__value_ <= 0;
85 return __v.__is_ordered() && __v.__value_ > 0;
88 return __v.__is_ordered() && __v.__value_ >= 0;
91 return __v.__is_ordered() && 0 == __v.__value_;
94 return __v.__is_ordered() && 0 < __v.__value_;
97 return __v.__is_ordered() && 0 <= __v.__value_;
100 return __v.__is_ordered() && 0 > __v.__value_;
103 return __v.__is_ordered() && 0 >= __v.__value_;
[all …]
/llvm-project-15.0.7/clang/test/CodeGenCXX/Inputs/
H A Dstd-compare.h76 return __v.__is_ordered() && __v.__value_ == 0;
79 return __v.__is_ordered() && __v.__value_ < 0;
82 return __v.__is_ordered() && __v.__value_ <= 0;
85 return __v.__is_ordered() && __v.__value_ > 0;
88 return __v.__is_ordered() && __v.__value_ >= 0;
91 return __v.__is_ordered() && 0 == __v.__value_;
94 return __v.__is_ordered() && 0 < __v.__value_;
97 return __v.__is_ordered() && 0 <= __v.__value_;
100 return __v.__is_ordered() && 0 > __v.__value_;
103 return __v.__is_ordered() && 0 >= __v.__value_;
[all …]
/llvm-project-15.0.7/libcxx/include/__compare/
H A Dordering.h77 return __v.__is_ordered() && __v.__value_ == 0;
82 return __v.__is_ordered() && __v.__value_ < 0;
87 return __v.__is_ordered() && __v.__value_ <= 0;
92 return __v.__is_ordered() && __v.__value_ > 0;
97 return __v.__is_ordered() && __v.__value_ >= 0;
102 return __v.__is_ordered() && 0 < __v.__value_;
107 return __v.__is_ordered() && 0 <= __v.__value_;
112 return __v.__is_ordered() && 0 > __v.__value_;
117 return __v.__is_ordered() && 0 >= __v.__value_;
127 return __v < 0 ? partial_ordering::greater : (__v > 0 ? partial_ordering::less : __v);
[all …]
/llvm-project-15.0.7/clang/lib/Headers/
H A D__clang_cuda_device_functions.h53 return __nvvm_atom_add_gen_d(__p, __v); in __dAtomicAdd()
56 return __nvvm_atom_cta_add_gen_d(__p, __v); in __dAtomicAdd_block()
59 return __nvvm_atom_sys_add_gen_d(__p, __v); in __dAtomicAdd_system()
177 return __nvvm_atom_add_gen_f(__p, __v); in __fAtomicAdd()
341 return __nvvm_atom_add_gen_i(__p, __v); in __iAtomicAdd()
350 return __nvvm_atom_and_gen_i(__p, __v); in __iAtomicAnd()
377 return __nvvm_atom_max_gen_i(__p, __v); in __iAtomicMax()
386 return __nvvm_atom_min_gen_i(__p, __v); in __iAtomicMin()
395 return __nvvm_atom_or_gen_i(__p, __v); in __iAtomicOr()
404 return __nvvm_atom_xor_gen_i(__p, __v); in __iAtomicXor()
[all …]
H A Dwasm_simd128.h59 __v128_u __v; in wasm_v128_load() member
67 uint8_t __v; in wasm_v128_load8_splat() member
70 return (v128_t)(__u8x16){__v, __v, __v, __v, __v, __v, __v, __v, in wasm_v128_load8_splat()
71 __v, __v, __v, __v, __v, __v, __v, __v}; in wasm_v128_load8_splat()
80 return (v128_t)(__u16x8){__v, __v, __v, __v, __v, __v, __v, __v}; in wasm_v128_load16_splat()
89 return (v128_t)(__u32x4){__v, __v, __v, __v}; in wasm_v128_load32_splat()
98 return (v128_t)(__u64x2){__v, __v}; in wasm_v128_load64_splat()
104 __i8x8 __v; in wasm_i16x8_load8x8() member
113 __u8x8 __v; in wasm_u16x8_load8x8() member
176 int8_t __v; in wasm_v128_load8_lane() member
[all …]
H A Dimmintrin.h363 unsigned short __v; in _loadbe_i16() member
365 return (short)__builtin_bswap16(((const struct __loadu_i16*)__P)->__v); in _loadbe_i16()
371 unsigned short __v; in _storebe_i16() member
373 ((struct __storeu_i16*)__P)->__v = __builtin_bswap16((unsigned short)__D); in _storebe_i16()
379 unsigned int __v; in _loadbe_i32() member
381 return (int)__builtin_bswap32(((const struct __loadu_i32*)__P)->__v); in _loadbe_i32()
387 unsigned int __v; in _storebe_i32() member
389 ((struct __storeu_i32*)__P)->__v = __builtin_bswap32((unsigned int)__D); in _storebe_i32()
396 unsigned long long __v; in _loadbe_i64() member
398 return (long long)__builtin_bswap64(((const struct __loadu_i64*)__P)->__v); in _loadbe_i64()
[all …]
H A D__clang_cuda_texture_intrinsics.h639 __device__ static __DestT __run(__SrcT __v);
640 template <> __device__ static __DestT __run<1>(__SrcT __v) { return {__v.x}; }
641 template <> __device__ static __DestT __run<2>(__SrcT __v) {
642 return {__v.x, __v.y};
644 template <> __device__ static __DestT __run<3>(__SrcT __v) {
645 return {__v.x, __v.y, __v.z};
647 template <> __device__ static __DestT __run<4>(__SrcT __v) {
648 return {__v.x, __v.y, __v.z, __v.w};
/llvm-project-15.0.7/libcxx/include/__functional/
H A Dhash.h281 __u.__t = __v;
298 __u.__t = __v;
319 __u.__t = __v;
341 __u.__t = __v;
364 __u.__t = __v;
393 __u.__t = __v;
550 if (__v == 0.0f)
564 if (__v == 0.0)
578 if (__v == 0.0L)
597 __u.__t = __v;
[all …]
/llvm-project-15.0.7/compiler-rt/lib/sanitizer_common/
H A Dsanitizer_linux.h141 ({ void** __v; __asm__("mrs %0, tpidr_el0" : "=r"(__v)); __v; })
144 ({ void** __v; __asm__("mrc p15, 0, %0, c13, c0, 3" : "=r"(__v)); __v; })
149 ({ register void** __v asm("v1"); \
153 ".set pop\n" : "=r"(__v)); \
154 __v; })
157 ({ void** __v; __asm__("movl %%gs:0, %0" : "=r"(__v)); __v; })
160 ({ void** __v; __asm__("mov %%fs:0, %0" : "=r"(__v)); __v; })
/llvm-project-15.0.7/libcxx/src/include/ryu/
H A Dcommon.h50 [[nodiscard]] _LIBCPP_HIDE_FROM_ABI inline uint32_t __decimalLength9(const uint32_t __v) { in __decimalLength9() argument
54 _LIBCPP_ASSERT(__v < 1000000000, ""); in __decimalLength9()
55 if (__v >= 100000000) { return 9; } in __decimalLength9()
56 if (__v >= 10000000) { return 8; } in __decimalLength9()
57 if (__v >= 1000000) { return 7; } in __decimalLength9()
58 if (__v >= 100000) { return 6; } in __decimalLength9()
59 if (__v >= 10000) { return 5; } in __decimalLength9()
60 if (__v >= 1000) { return 4; } in __decimalLength9()
61 if (__v >= 100) { return 3; } in __decimalLength9()
62 if (__v >= 10) { return 2; } in __decimalLength9()
/llvm-project-15.0.7/libcxx/src/ryu/
H A Dd2s.cpp168 if (__v >= 1000000u) { return 7; } in __decimalLength17()
169 if (__v >= 100000u) { return 6; } in __decimalLength17()
170 if (__v >= 10000u) { return 5; } in __decimalLength17()
171 if (__v >= 1000u) { return 4; } in __decimalLength17()
172 if (__v >= 100u) { return 3; } in __decimalLength17()
173 if (__v >= 10u) { return 2; } in __decimalLength17()
698 __v->__mantissa = __m2 >> -__e2; in __d2d_small_int()
699 __v->__exponent = 0; in __d2d_small_int()
758 __floating_decimal_64 __v; in __d2s_buffered_n() local
771 __v.__mantissa = __q; in __d2s_buffered_n()
[all …]
/llvm-project-15.0.7/libcxx/include/__algorithm/
H A Dclamp.h27 clamp(const _Tp& __v, const _Tp& __lo, const _Tp& __hi, _Compare __comp) in clamp() argument
30 return __comp(__v, __lo) ? __lo : __comp(__hi, __v) ? __hi : __v; in clamp()
38 clamp(const _Tp& __v, const _Tp& __lo, const _Tp& __hi) in clamp() argument
40 return _VSTD::clamp(__v, __lo, __hi, __less<_Tp>()); in clamp()
/llvm-project-15.0.7/lldb/tools/debugserver/source/MacOSX/arm64/
H A DDNBArchImplARM64.cpp260 ((uint64_t *)&m_state.context.vfp.__v[0])[0], in GetVFPState()
261 ((uint64_t *)&m_state.context.vfp.__v[0])[1], in GetVFPState()
262 ((uint64_t *)&m_state.context.vfp.__v[1])[0], in GetVFPState()
263 ((uint64_t *)&m_state.context.vfp.__v[1])[1], in GetVFPState()
264 ((uint64_t *)&m_state.context.vfp.__v[2])[0], in GetVFPState()
265 ((uint64_t *)&m_state.context.vfp.__v[2])[1], in GetVFPState()
266 ((uint64_t *)&m_state.context.vfp.__v[3])[0], in GetVFPState()
267 ((uint64_t *)&m_state.context.vfp.__v[3])[1], in GetVFPState()
268 ((uint64_t *)&m_state.context.vfp.__v[4])[0], in GetVFPState()
269 ((uint64_t *)&m_state.context.vfp.__v[4])[1], in GetVFPState()
[all …]
/llvm-project-15.0.7/lldb/tools/debugserver/source/MacOSX/arm/
H A DDNBArchImpl.cpp228 ((uint64_t *)&m_state.context.vfp.__v[0])[1], in GetVFPState()
229 ((uint64_t *)&m_state.context.vfp.__v[1])[0], in GetVFPState()
230 ((uint64_t *)&m_state.context.vfp.__v[1])[1], in GetVFPState()
231 ((uint64_t *)&m_state.context.vfp.__v[2])[0], in GetVFPState()
232 ((uint64_t *)&m_state.context.vfp.__v[2])[1], in GetVFPState()
233 ((uint64_t *)&m_state.context.vfp.__v[3])[0], in GetVFPState()
234 ((uint64_t *)&m_state.context.vfp.__v[3])[1], in GetVFPState()
235 ((uint64_t *)&m_state.context.vfp.__v[4])[0], in GetVFPState()
236 ((uint64_t *)&m_state.context.vfp.__v[4])[1], in GetVFPState()
237 ((uint64_t *)&m_state.context.vfp.__v[5])[0], in GetVFPState()
[all …]
/llvm-project-15.0.7/libcxx/include/
H A Dvalarray416 begin(valarray<_Tp>& __v);
426 end(valarray<_Tp>& __v);
1358 *__t = __v[__i];
2879 if (__v.size())
2905 __end_(__v.__end_)
2907 __v.__begin_ = __v.__end_ = nullptr;
3082 return __assign_range(__v.__begin_, __v.__end_);
3095 __end_ = __v.__end_;
4918 end(valarray<_Tp>& __v)
4920 return __v.__end_;
[all …]
H A Dvector791 : __v_(__v), __pos_(__v.__end_), __new_end_(__v.__end_ + __n) {
930 __v.__first_ = __v.__begin_;
950 __v.__first_ = __v.__begin_;
1572 __v.__end_++;
1614 __v.__end_++;
2775 __construct_at_end(__v.begin(), __v.end());
2789 __construct_at_end(__v.begin(), __v.end());
2808 … _VSTD::copy(__v.__begin_, __v.__begin_ + __external_cap_to_internal(__v.__size_), __begin_);
2843 __v.__cap() = __v.__size_ = 0;
2848 __construct_at_end(__v.begin(), __v.end());
[all …]
H A D__tree568 return __v;
572 return __v;
626 return __v.__move();
1255 return __emplace_unique_key_args(_NodeTypes::__get_key(__v), __v);
1935 // __v <= *__hint
1954 // else __v > *__hint
1961 // If __v exists, set parent to node of __v and return reference to node of __v
2011 // If __v exists, set parent to node of __v and return reference to node of __v
2022 // __v < *__hint
2043 // *__hint < __v
[all …]
H A Dbitset190 void operator&=(const __bitset& __v) _NOEXCEPT;
260 __first_[0] = __v;
275 : __first_{__v}
277 : __first_{static_cast<__storage_type>(__v),
296 __first_[__i] &= __v.__first_[__i];
305 __first_[__i] |= __v.__first_[__i];
314 __first_[__i] ^= __v.__first_[__i];
533 __first_ &= __v.__first_;
541 __first_ |= __v.__first_;
549 __first_ ^= __v.__first_;
[all …]
H A Doptional775 constexpr optional(_Up&& __v)
782 constexpr explicit optional(_Up&& __v)
792 this->__construct_from(__v);
800 this->__construct_from(__v);
854 operator=(_Up&& __v)
869 operator=(const optional<_Up>& __v)
871 this->__assign_from(__v);
881 operator=(optional<_Up>&& __v)
883 this->__assign_from(_VSTD::move(__v));
1053 constexpr value_type value_or(_Up&& __v) &&
[all …]
H A Dtypeinfo196 return __v;
200 return __v;
206 static size_t __hash(__type_name_t __v) _NOEXCEPT {
207 return reinterpret_cast<size_t>(__v);
241 static const char* __type_name_to_string(__type_name_t __v) _NOEXCEPT {
242 return reinterpret_cast<const char*>(__v &
247 return reinterpret_cast<__type_name_t>(__v);
251 static size_t __hash(__type_name_t __v) _NOEXCEPT {
252 if (__is_type_name_unique(__v))
253 return __v;
[all …]
H A Dvariant1476 return __v.index() == _Ip;
1500 variant<_Types...>& __v) {
1503 return __generic_get<_Ip>(__v);
1510 variant<_Types...>&& __v) {
1520 const variant<_Types...>& __v) {
1523 return __generic_get<_Ip>(__v);
1550 _VSTD::move(__v));
1567 _VSTD::move(__v));
1574 return __v && __holds_alternative<_Ip>(*__v)
1585 return __generic_get_if<_Ip>(__v);
[all …]
/llvm-project-15.0.7/libcxx/include/__random/
H A Dpoisson_distribution.h217 double __v = __difmuk / __tx; in operator() local
218 if (_VSTD::abs(__v) > 0.25) in operator()
219 __px = __tx * _VSTD::log(1 + __v) - __difmuk - __del; in operator()
221 __px = __tx * __v * __v * (((((((.1250060 * __v + -.1384794) * in operator()
222 __v + .1421878) * __v + -.1661269) * __v + .2000118) * in operator()
223 __v + -.2500068) * __v + .3333333) * __v + -.5) - __del; in operator()
/llvm-project-15.0.7/clang/test/PCH/
H A Dchain-staticvar-instantiation.cpp13 template <class _Tp, _Tp __v>
16 static const _Tp value = __v;
19 template <class _Tp, _Tp __v>
20 const _Tp TS<_Tp, __v>::value;
/llvm-project-15.0.7/libcxx/include/__type_traits/
H A Dintegral_constant.h20 template <class _Tp, _Tp __v>
23 static _LIBCPP_CONSTEXPR const _Tp value = __v;
34 template <class _Tp, _Tp __v>
35 _LIBCPP_CONSTEXPR const _Tp integral_constant<_Tp, __v>::value;

1234